@@ -7,14 +7,30 @@ github3.api
 
 """
 
-from .github import GitHub, GitHubEnterprise  # NOQA
+from .github import GitHub
 
 gh = GitHub()
 
 
-def authorize(login, password, scopes, note='', note_url=''):
-    """See :func:`authorize <github3.github.GitHub.authorize>`"""
-    return gh.authorize(login, password, scopes, note, note_url)
+def authorize(login, password, scopes, note='', note_url='', client_id='',
+              client_secret=''):
+    """Obtain an authorization token from the GitHub API for the GitHub
+    API.
+
+    :param str login: (required)
+    :param str password: (required)
+    :param list scopes: (required), areas you want this token to apply to,
+        i.e., 'gist', 'user'
+    :param str note: (optional), note about the authorization
+    :param str note_url: (optional), url for the application
+    :param str client_id: (optional), 20 character OAuth client key for which
+        to create a token
+    :param str client_secret: (optional), 40 character OAuth client secret for
+        which to create the token
+    :returns: :class:`Authorization <Authorization>`
+    """
+    return gh.authorize(login, password, scopes, note, note_url, client_id,
+                        client_secret)
 
 
 def login(username=None, password=None, token=None):
@@ -42,6 +58,42 @@ def gist(id_num):
     return gh.gist(id_num)
 
 
+def gitignore_template(language):
+    """Returns the template for language.
+
+    :returns: str
+    """
+    return gh.gitignore_template(language)
+
+
+def gitignore_templates():
+    """Returns the list of available templates.
+
+    :returns: list of template names
+    """
+    return gh.gitignore_templates()
+
+
+def iter_all_repos(number=-1):
+    """Iterate over every repository in the order they were created.
+
+    :param int number: (optional), number of repositories to return.
+        Default: -1, returns all of them
+    :returns: generator of :class:`Repository <github3.repos.Repository>`
+    """
+    return gh.iter_all_repos(number)
+
+
+def iter_all_users(number=-1):
+    """Iterate over every user in the order they signed up for GitHub.
+
+    :param int number: (optional), number of users to return. Default: -1,
+        returns all of them
+    :returns: generator of :class:`User <github3.users.User>`
+    """
+    return gh.iter_all_users(number)
+
+
 def iter_events(number=-1):
     """Iterate over public events.
 
@@ -113,7 +165,7 @@ def iter_repo_issues(owner, repository, filter='', state='', labels='',
     """
     if owner and repository:
         return gh.iter_repo_issues(owner, repository, filter, state, labels,
-                                     sort, direction, since, number)
+                                   sort, direction, since, number)
     return iter([])
 
 
@@ -245,6 +297,7 @@ def search_issues(owner, repo, state, keyword):
     :param str repo: (required)
     :param str state: (required), accepted values: ('open', 'closed')
     :param str keyword: (required), what to search for
+    :param int start_page: (optional), page to get (results come 100/page)
     :returns: list of :class:`LegacyIssue <github3.legacy.LegacyIssue>`\ s
     """
     return gh.search_issues(owner, repo, state, keyword)
@@ -253,10 +306,9 @@ def search_issues(owner, repo, state, keyword):
 def search_repos(keyword, **params):
     """Search all repositories by keyword.
 
-    :param keyword: (required)
-    :type keyword: str
-    :param params: (optional), filter by language and/or start_page
-    :type params: dict
+    :param str keyword: (required)
+    :param str language: (optional), language to filter by
+    :param int start_page: (optional), page to get (results come 100/page)
     :returns: list of :class:`LegacyRepo <github3.legacy.LegacyRepo>`\ s
     """
     return gh.search_repos(keyword, **params)
@@ -266,6 +318,7 @@ def search_users(keyword):
     """Search all users by keyword.
 
     :param str keyword: (required)
+    :param int start_page: (optional), page to get (results come 100/page)
     :returns: list of :class:`LegacyUser <github3.legacy.LegacyUser>`\ s
     """
     return gh.search_users(keyword)
@@ -287,7 +340,7 @@ def user(login):
 
 def ratelimit_remaining():
     """Get the remaining number of requests allowed."""
-    return gh.ratelimit_remaining
+    return gh.ratelimit_remaining()
 
 
 def zen():
