@@ -61,5 +61,5 @@ def requires_basic_auth(func):
 
 # Use mock decorators when generating documentation, so all functino signatures
 # are displayed correctly
-if os.environ.get('GENERATING_DOCUMENTATION', None) == 'github3':
-    requires_auth = requires_basic_auth = lambda x: x
+if os.getenv('GENERATING_DOCUMENTATION', None) == 'github3':
+    requires_auth = requires_basic_auth = lambda x: x  # (No coverage)
