@@ -103,7 +103,7 @@ class GitHub(GitHubCore):
             else:
                 ses = session()
                 ses.auth = (login, password)
-                json = self._json(ses.post(url, data=data), 201)
+                json = self._json(ses.post(url, data=dumps(data)), 201)
         return Authorization(json, self) if json else None
 
     def create_gist(self, description, files, public=True):
@@ -614,11 +614,10 @@ class GitHub(GitHubCore):
         params = {}
         if type in ('all', 'owner', 'public', 'private', 'member'):
             params.update(type=type)
-        if not login:
-            if sort in ('created', 'updated', 'pushed', 'full_name'):
-                params.update(sort=sort)
-            if direction in ('asc', 'desc'):
-                params.update(direction=direction)
+        if sort in ('created', 'updated', 'pushed', 'full_name'):
+            params.update(sort=sort)
+        if direction in ('asc', 'desc'):
+            params.update(direction=direction)
 
         return self._iter(int(number), url, Repository, params=params)
 
@@ -717,17 +716,6 @@ class GitHub(GitHubCore):
                 return req.content
         return ''  # (No coverage)
 
-    def pull_request(self, owner, repository, number):
-        """Fetch pull_request #:number: from :owner:/:repository
-
-        :param str owner: (required), owner of the repository
-        :param str repository: (required), name of the repository
-        :param int number: (required), issue number
-        :return: :class:`Issue <github3.issues.Issue>`
-        """
-        r = self.repository(owner, repository)
-        return r.pull_request(number) if r else None
-
     def octocat(self):
         """Returns an easter egg of the API."""
         url = self._build_url('octocat')
@@ -744,6 +732,47 @@ class GitHub(GitHubCore):
         json = self._json(self._get(url), 200)
         return Organization(json, self) if json else None
 
+    @requires_auth
+    def pubsubhubbub(self, mode, topic, callback, secret=''):
+        """Create/update a pubsubhubbub hook.
+
+        :param str mode: (required), accepted values: ('subscribe',
+            'unsubscribe')
+        :param str topic: (required), form:
+            https://github.com/:user/:repo/events/:event
+        :param str callback: (required), the URI that receives the updates
+        :param str secret: (optional), shared secret key that generates a
+            SHA1 HMAC of the payload content.
+        :returns: bool
+        """
+        from re import match
+        m = match('https://github\.com/\w+/[\w\._-]+/events/\w+', topic)
+        status = False
+        if mode and topic and callback and m:
+            data = [('hub.mode', mode), ('hub.topic', topic),
+                    ('hub.callback', callback)]
+            if secret:
+                data.append(('hub.secret', secret))
+            url = self._build_url('hub')
+            h = {'Content-Type': None}
+            # This is not JSON data. It is meant to be form data
+            # application/x-www-form-urlencoded works fine here, no need for
+            # multipart/form-data
+            status = self._boolean(self._post(url, data=data, headers=h), 204,
+                                   404)
+        return status
+
+    def pull_request(self, owner, repository, number):
+        """Fetch pull_request #:number: from :owner:/:repository
+
+        :param str owner: (required), owner of the repository
+        :param str repository: (required), name of the repository
+        :param int number: (required), issue number
+        :return: :class:`Issue <github3.issues.Issue>`
+        """
+        r = self.repository(owner, repository)
+        return r.pull_request(number) if r else None
+
     def repository(self, owner, repository):
         """Returns a Repository object for the specified combination of
         owner and repository
