@@ -71,8 +71,8 @@ class Team(GitHubCore):
         :returns: bool
         """
         if name:
-            data = dumps({'name': name, 'permission': permission})
-            json = self._json(self._patch(self._api, data=data), 200)
+            data = {'name': name, 'permission': permission}
+            json = self._json(self._patch(self._api, data=dumps(data)), 200)
             if json:
                 self._update_(json)
                 return True
@@ -106,15 +106,6 @@ class Team(GitHubCore):
         url = self._build_url('members', base_url=self._api)
         return self._iter(int(number), url, User)
 
-    def list_members(self):
-        """List the members of this team.
-
-        :returns: list of :class:`User <github3.users.User>`\ s
-        """
-        url = self._build_url('members', base_url=self._api)
-        json = self._json(self._get(url), 200)
-        return [User(m, self) for m in json]
-
     def iter_repos(self, number=-1):
         """Iterate over the repositories this team has access to.
 
@@ -126,16 +117,6 @@ class Team(GitHubCore):
         url = self._build_url('repos', base_url=self._api)
         return self._iter(int(number), url, Repository)
 
-    def list_repos(self):
-        """List the repositories this team has access to.
-
-        :returns: list of :class:`Repository <github3.repos.Repository>`
-            objects
-        """
-        url = self._build_url('repos', base_url=self._api)
-        json = self._json(self._get(url), 200)
-        return [Repository(r, self) for r in json]
-
     @requires_auth
     def remove_member(self, login):
         """Remove ``login`` from this team.
@@ -170,12 +151,6 @@ class Organization(BaseAccount):
     def __repr__(self):
         return '<Organization [{0}:{1}]>'.format(self.login, self.name)
 
-    def _list_members(self, tail):
-        """List members of this organization."""
-        url = self._api + tail
-        json = self._json(self._get(url), 200)
-        return [User(memb, self) for memb in json]
-
     @requires_auth
     def add_member(self, login, team):
         """Add ``login`` to ``team`` and thereby to this organization.
@@ -187,8 +162,7 @@ class Organization(BaseAccount):
         :param str team: (required), team name
         :returns: bool
         """
-        teams = self.list_teams()
-        for t in teams:
+        for t in self.iter_teams():
             if team == t.name:
                 return t.add_member(login)
         return False
@@ -200,8 +174,7 @@ class Organization(BaseAccount):
         :param str repo: (required), form: 'user/repo'
         :param str team: (required)
         """
-        teams = self.list_teams()
-        for t in teams:
+        for t in self.iter_teams():
             if team == t.name:
                 return t.add_repo(repo)
         return False
@@ -249,7 +222,7 @@ class Organization(BaseAccount):
                 'gitignore_template': gitignore_template}
         if team_id > 0:
             data.update({'team_id': team_id})
-        json = self._json(self._post(url, dumps(data)), 201)
+        json = self._json(self._post(url, data), 201)
         return Repository(json, self) if json else None
 
     @requires_auth
@@ -280,8 +253,8 @@ class Organization(BaseAccount):
 
         :returns: :class:`Team <Team>`
         """
-        data = dumps({'name': name, 'repo_names': repo_names,
-                      'permissions': permissions})
+        data = {'name': name, 'repo_names': repo_names,
+                'permissions': permissions}
         url = self._build_url('teams', base_url=self._api)
         json = self._json(self._post(url, data), 201)
         return Team(json, self._session) if json else None
@@ -343,15 +316,6 @@ class Organization(BaseAccount):
         url = self._build_url('events', base_url=self._api)
         return self._iter(int(number), url, Event)
 
-    def list_events(self):
-        """List events for this org.
-
-        :returns: list of :class:`Event <github3.events.Event>`\ s
-        """
-        url = self._build_url('events', base_url=self._api)
-        json = self._json(self._get(url), 200)
-        return [Event(e, self._session) for e in json]
-
     def iter_members(self, number=-1):
         """Iterate over members of this organization.
 
@@ -362,13 +326,6 @@ class Organization(BaseAccount):
         url = self._build_url('members', base_url=self._api)
         return self._iter(int(number), url, User)
 
-    def list_members(self):
-        """List members of this organization.
-
-        :returns: list of :class:`User <github3.users.User>`\ s
-        """
-        return self._list_members('/members')
-
     def iter_public_members(self, number=-1):
         """Iterate over public members of this organization.
 
@@ -379,41 +336,21 @@ class Organization(BaseAccount):
         url = self._build_url('public_members', base_url=self._api)
         return self._iter(int(number), url, User)
 
-    def list_public_members(self):
-        """List public members of this organization.
-
-        :returns: list of :class:`User <github3.users.User>`\ s
-        """
-        return self._list_members('/public_members')
-
     def iter_repos(self, type='', number=-1):
         """Iterate over repos for this organization.
 
         :param str type: (optional), accepted values:
-            ('all', 'public', 'member', 'private'), API default: 'all'
+            ('all', 'public', 'member', 'private', 'forks', 'sources'), API
+            default: 'all'
         :param int number: (optional), number of members to return. Default:
             -1 will return all available.
         :returns: generator of :class:`Repository <github3.repos.Repository>`
         """
         url = self._build_url('repos', base_url=self._api)
-        if type in ('all', 'public', 'member', 'private'):
-            url = '{0}?type={1}'.format(url, type)
-        return self._iter(int(number), url, Repository)
-
-    def list_repos(self, type=''):
-        """List repos for this organization.
-
-        :param str type: (optional), accepted values:
-            ('all', 'public', 'member', 'private'), API default: 'all'
-        :returns: list of :class:`Repository <github3.repos.Repository>`
-            objects
-        """
-        url = self._build_url('repos', base_url=self._api)
         params = {}
-        if type in ('all', 'public', 'member', 'private'):
+        if type in ('all', 'public', 'member', 'private', 'forks', 'sources'):
             params['type'] = type
-        json = self._json(self._get(url, params=params), 200)
-        return [Repository(r, self) for r in json]
+        return self._iter(int(number), url, Repository, params)
 
     @requires_auth
     def iter_teams(self, number=-1):
@@ -426,16 +363,6 @@ class Organization(BaseAccount):
         url = self._build_url('teams', base_url=self._api)
         return self._iter(int(number), url, Team)
 
-    @requires_auth
-    def list_teams(self):
-        """List teams that are part of this organization.
-
-        :returns: list of :class:`Team <Team>`\ s
-        """
-        url = self._build_url('teams', base_url=self._api)
-        json = self._json(self._get(url), 200)
-        return [Team(team, self) for team in json]
-
     @requires_auth
     def publicize_member(self, login):
         """Make ``login``'s membership in this organization public.
@@ -463,8 +390,7 @@ class Organization(BaseAccount):
         :param str team: (required)
         :returns: bool
         """
-        teams = self.list_teams()
-        for t in teams:
+        for t in self.iter_teams():
             if team == t.name:
                 return t.remove_repo(repo)
         return False
