@@ -8,7 +8,6 @@ This module contains the classes relating to repositories.
 
 from json import dumps
 from base64 import b64decode
-from requests import post
 from collections import Callable
 from github3.events import Event
 from github3.issues import Issue, IssueEvent, Label, Milestone, issue_params
@@ -40,6 +39,9 @@ class Repository(GitHubCore):
         #: Is this repository a fork?
         self.fork = repo.get('fork')
 
+        #: Full name as login/name
+        self.full_name = repo.get('full_name', '')
+
         # Clone url using git, e.g. git://github.com/sigmavirus24/github3.py
         #: Plain git url for an anonymous clone.
         self.git_url = repo.get('git_url', '')
@@ -116,12 +118,13 @@ class Repository(GitHubCore):
         return '<Repository [{0}]>'.format(self)
 
     def __str__(self):
-        return '{0}/{1}'.format(self.owner, self.name)
+        return self.full_name
 
     def _update_(self, repo):
         self.__init__(repo, self._session)
 
     def _create_pull(self, data):
+        self._remove_none(data)
         json = None
         if data:
             url = self._build_url('pulls', base_url=self._api)
@@ -325,52 +328,6 @@ class Repository(GitHubCore):
             json = self._json(self._post(url, data=dumps(data)), 201)
         return Commit(json, self) if json else None
 
-    @requires_auth
-    def create_download(self, name, path, description='',
-                        content_type='text/plain'):
-        """Create a new download on this repository.
-
-        I do not require you provide the size in bytes because it can be
-        determined by the operating system.
-
-        .. warning::
-
-            On 2012-03-11, GitHub will be deprecating the Downloads API. This
-            method will no longer work.
-
-        :param str name: (required), name of the file as it will appear
-        :param str path: (required), path to the file
-        :param str description: (optional), description of the file
-        :param str content_type: (optional), e.g. 'text/plain'
-        :returns: :class:`Download <Download>` if successful, else None
-        """
-        json = None
-        if name and path:
-            url = self._build_url('downloads', base_url=self._api)
-            from os import stat
-            info = stat(path)
-            data = {'name': name, 'size': info.st_size,
-                    'description': description,
-                    'content_type': content_type}
-            json = self._json(self._post(url, data=dumps(data)), 201)
-
-        if not json:
-            return None
-
-        form = [('key', json.get('path')),
-                ('acl', json.get('acl')),
-                ('success_action_status', '201'),
-                ('Filename', json.get('name')),
-                ('AWSAccessKeyId', json.get('accesskeyid')),
-                ('Policy', json.get('policy')),
-                ('Signature', json.get('signature')),
-                ('Content-Type', json.get('mime_type'))]
-        file = [('file', open(path, 'rb').read())]
-        resp = post(json.get('s3_url'), data=form, files=file,
-                    headers={'Accept-Charset': 'utf-8'})
-
-        return Download(json, self) if self._boolean(resp, 201, 404) else None
-
     @requires_auth
     def create_fork(self, organization=None):
         """Create a fork of this repository.
@@ -488,7 +445,7 @@ class Repository(GitHubCore):
         """
         url = self._build_url('milestones', base_url=self._api)
         if state not in ('open', 'closed'):
-            state = 'open'
+            state = None
         data = {'title': title, 'state': state,
                 'description': description, 'due_on': due_on}
         self._remove_none(data)
@@ -498,7 +455,7 @@ class Repository(GitHubCore):
         return Milestone(json, self) if json else None
 
     @requires_auth
-    def create_pull(self, title, base, head, body=''):
+    def create_pull(self, title, base, head, body=None):
         """Create a pull request using commits from ``head`` and comparing
         against ``base``.
 
@@ -523,8 +480,10 @@ class Repository(GitHubCore):
         :returns: :class:`PullRequest <github3.pulls.PullRequest>` if
             successful, else None
         """
-        data = {'issue': issue, 'base': base, 'head': head}
-        return self._create_pull(data)
+        if issue > 0:
+            data = {'issue': issue, 'base': base, 'head': head}
+            return self._create_pull(data)
+        return None
 
     @requires_auth
     def create_ref(self, ref, sha):
@@ -537,9 +496,11 @@ class Repository(GitHubCore):
         :returns: :class:`Reference <github3.git.Reference>` if successful
             else None
         """
-        data = {'ref': ref, 'sha': sha}
-        url = self._build_url('git', 'refs', base_url=self._api)
-        json = self._json(self._post(url, data), 201)
+        json = None
+        if ref and ref.count('/') >= 2 and sha:
+            data = {'ref': ref, 'sha': sha}
+            url = self._build_url('git', 'refs', base_url=self._api)
+            json = self._json(self._post(url, data=dumps(data)), 201)
         return Reference(json, self) if json else None
 
     @requires_auth
@@ -586,7 +547,7 @@ class Repository(GitHubCore):
             data = {'tag': tag, 'message': message, 'object': sha,
                     'type': obj_type, 'tagger': tagger}
             url = self._build_url('git', 'tags', base_url=self._api)
-            json = self._json(self._post(url, data), 201)
+            json = self._json(self._post(url, data=dumps(data)), 201)
             if json:
                 self.create_ref('refs/tags/' + tag, sha)
         return Tag(json) if json else None
@@ -606,7 +567,7 @@ class Repository(GitHubCore):
         if tree and isinstance(tree, list):
             data = {'tree': tree, 'base_tree': base_tree}
             url = self._build_url('git', 'trees', base_url=self._api)
-            json = self._json(self._post(url, data), 201)
+            json = self._json(self._post(url, data=dumps(data)), 201)
         return Tree(json) if json else None
 
     @requires_auth
@@ -686,11 +647,12 @@ class Repository(GitHubCore):
                 'has_wiki': has_wiki, 'has_downloads': has_downloads,
                 'default_branch': default_branch}
         self._remove_none(edit)
-        json = self._json(self._patch(self._api, data=dumps(edit)), 200)
-        if json:
+        json = None
+        if edit:
+            json = self._json(self._patch(self._api, data=dumps(edit)), 200)
             self._update_(json)
             return True
-        return False  # (No coverage)
+        return False
 
     def is_collaborator(self, login):
         """Check to see if ``login`` is a collaborator on this repository.
@@ -703,20 +665,6 @@ class Repository(GitHubCore):
             return self._boolean(self._get(url), 204, 404)
         return False
 
-    def is_fork(self):
-        """Checks if this repository is a fork.
-
-        :returns: bool
-        """
-        return self.fork
-
-    def is_private(self):
-        """Checks if this repository is private.
-
-        :returns: bool
-        """
-        return self.private
-
     def git_commit(self, sha):
         """Get a single (git) commit.
 
@@ -724,8 +672,10 @@ class Repository(GitHubCore):
         :returns: :class:`Commit <github3.git.Commit>` if successful,
             otherwise None
         """
-        url = self._build_url('git', 'commits', sha, base_url=self._api)
-        json = self._json(self._get(url), 200)
+        json = {}
+        if sha:
+            url = self._build_url('git', 'commits', sha, base_url=self._api)
+            json = self._json(self._get(url), 200)
         return Commit(json, self) if json else None
 
     @requires_auth
@@ -747,6 +697,8 @@ class Repository(GitHubCore):
 
         :returns: :class:`bool`
         """
+        if not login:
+            return False
         url = self._build_url('assignees', login, base_url=self._api)
         return self._boolean(self._get(url), 204, 404)
 
@@ -832,7 +784,7 @@ class Repository(GitHubCore):
         url = self._build_url('commits', sha, 'comments', base_url=self._api)
         return self._iter(int(number), url, RepoComment)
 
-    def iter_commits(self, sha='', path='', author='', number=-1):
+    def iter_commits(self, sha=None, path=None, author=None, number=-1):
         """Iterate over commits in this repository.
 
         :param str sha: (optional), sha or branch to start listing commits
@@ -846,13 +798,8 @@ class Repository(GitHubCore):
 
         :returns: list of :class:`RepoCommit <RepoCommit>`\ s
         """
-        params = {}
-        if sha:
-            params['sha'] = sha
-        if path:
-            params['path'] = path
-        if author:
-            params['author'] = author
+        params = {'sha': sha, 'path': path, 'author': author}
+        self._remove_none(params)
         url = self._build_url('commits', base_url=self._api)
         return self._iter(int(number), url, RepoCommit, params=params)
 
@@ -868,7 +815,7 @@ class Repository(GitHubCore):
         url = self._build_url('contributors', base_url=self._api)
         params = {}
         if anon:
-            params = {'anon': anon}
+            params = {'anon': True}
         return self._iter(int(number), url, User, params=params)
 
     def iter_downloads(self, number=-1):
@@ -1199,9 +1146,12 @@ class Repository(GitHubCore):
         status = False
         if mode and topic and callback and m:
             data = [('hub.mode', mode), ('hub.topic', topic),
-                    ('hub.callback', callback), ('hub.secret', secret)]
+                    ('hub.callback', callback)]
+            if secret:
+                data.append(('hub.secret', secret))
             url = self._build_url('hub')
-            status = self._boolean(self._post(url, data=dumps(data)), 204,
+            h = {'Content-Type': None}
+            status = self._boolean(self._post(url, data=data, headers=h), 204,
                                    404)
         return status
 
@@ -1540,13 +1490,6 @@ class Hook(GitHubCore):
             return True
         return False
 
-    def is_active(self):
-        """Checks whether the hook is marked as active on GitHub or not.
-
-        :returns: bool
-        """
-        return self.active
-
     @requires_auth
     def test(self):
         """Test this hook
